==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebDocumentHostDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebDocumentHostDescription } from "./WebDocumentHostDescription";
/**
 * @hidden
 */
var WebDocumentHostDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDocumentHostDescriptionMetadata, _super);
    function WebDocumentHostDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDocumentHostDescriptionMetadata.b = function (a) {
        if (WebDocumentHostDescriptionMetadata.a == null) {
            WebDocumentHostDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDocumentHostDescriptionMetadata.c(WebDocumentHostDescriptionMetadata.a);
        }
        if (a.g(WebDocumentHostDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDocumentHostDescriptionMetadata.a);
        WebSplitPaneDescriptionMetadata.d(a);
    };
    WebDocumentHostDescriptionMetadata.c = function (a) {
        WebDockManagerPaneDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:DocumentHost");
        a.item("Id", "String");
        a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
        a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
        a.item("RootPane", "ExportedType:WebSplitPane");
        a.item("Size", "Number:double");
    };
    WebDocumentHostDescriptionMetadata.d = function (a) {
        WebDocumentHostDescriptionMetadata.b(a);
        a.u("WebDocumentHost", function () { return new WebDocumentHostDescription(); });
        a.t("WebDocumentHost", WebDocumentHostDescriptionMetadata.a);
    };
    WebDocumentHostDescriptionMetadata.$t = markType(WebDocumentHostDescriptionMetadata, 'WebDocumentHostDescriptionMetadata');
    WebDocumentHostDescriptionMetadata.a = null;
    return WebDocumentHostDescriptionMetadata;
}(Base));
export { WebDocumentHostDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebDocumentHostDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebDocumentHostDescription } from "./WebDocumentHostDescription";
/**
 * @hidden
 */
var WebDocumentHostDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDocumentHostDescriptionMetadata, _super);
    function WebDocumentHostDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDocumentHostDescriptionMetadata.b = function (a) {
        if (WebDocumentHostDescriptionMetadata.a == null) {
            WebDocumentHostDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDocumentHostDescriptionMetadata.c(WebDocumentHostDescriptionMetadata.a);
        }
        if (a.j(WebDocumentHostDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDocumentHostDescriptionMetadata.a);
        WebSplitPaneDescriptionMetadata.d(a);
    };
    WebDocumentHostDescriptionMetadata.c = function (a) {
        WebDockManagerPaneDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:DocumentHost");
        a.item("Id", "String");
        a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
        a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
        a.item("RootPane", "ExportedType:WebSplitPane");
        a.item("Size", "Number:double");
    };
    WebDocumentHostDescriptionMetadata.d = function (a) {
        WebDocumentHostDescriptionMetadata.b(a);
        a.aa("WebDocumentHost", function () { return new WebDocumentHostDescription(); });
        a.z("WebDocumentHost", WebDocumentHostDescriptionMetadata.a);
    };
    WebDocumentHostDescriptionMetadata.$t = markType(WebDocumentHostDescriptionMetadata, 'WebDocumentHostDescriptionMetadata');
    WebDocumentHostDescriptionMetadata.a = null;
    return WebDocumentHostDescriptionMetadata;
}(Base));
export { WebDocumentHostDescriptionMetadata };
